pub enum Error<C: CodingScheme> {
Coding(C::Error),
Codec(Error),
DigestMismatch,
ConfigMismatch,
ContextMismatch,
}Expand description
An error that can occur during reconstruction of a CodedBlock from Shards
Variants
Coding(C::Error)
An error occurred while recovering the encoded blob from the Shards
Codec(Error)
An error occurred while decoding the reconstructed blob into a CodedBlock
DigestMismatch
The reconstructed block’s digest does not match the commitment’s block digest
ConfigMismatch
The reconstructed block’s config does not match the commitment’s coding config
ContextMismatch
The reconstructed block’s embedded context does not match the commitment context digest