Config

Struct Config 

pub struct Config<P, S, X, D, C, H, B, T>
where P: PublicKey, S: Provider<Scope = Epoch>, X: Blocker<PublicKey = P>, D: PeerProvider<PublicKey = P>, C: CodingScheme, H: Hasher, B: CertifiableBlock, T: Strategy,
{ pub scheme_provider: S, pub blocker: X, pub shard_codec_cfg: <Shard<C, H> as Read>::Cfg, pub block_codec_cfg: B::Cfg, pub strategy: T, pub mailbox_size: usize, pub peer_buffer_size: NonZeroUsize, pub background_channel_capacity: usize, pub peer_provider: D, }
Configuration for the Engine.

Fields

scheme_provider: S

The scheme provider.

blocker: X

The peer blocker.

shard_codec_cfg: <Shard<C, H> as Read>::Cfg

Read configuration for decoding Shards.

block_codec_cfg: B::Cfg

commonware_codec::Read configuration for decoding blocks.

strategy: T

The strategy used for parallel computation.

mailbox_size: usize

The size of the mailbox buffer.

peer_buffer_size: NonZeroUsize

Number of shards to buffer per peer.

Shards for commitments without a reconstruction state are buffered per peer in a fixed-size ring to bound memory under Byzantine spam. These shards are only ingested when consensus provides a leader via Discovered.

The worst-case total memory usage for the set of shard buffers is num_participants * peer_buffer_size * max_shard_size.

background_channel_capacity: usize

Capacity of the channel between the background receiver and the engine.

The background receiver decodes incoming network messages in a separate task and forwards them to the engine over an mpsc channel with this capacity.

peer_provider: D

Provider for peer set information. Per-peer shard buffers are freed when a peer leaves all tracked peer sets.