pub struct Engine<E, S, X, D, C, H, B, P, T>where
E: BufferPooler + Rng + Spawner + Metrics + Clock,
S: Provider<Scope = Epoch>,
S::Scheme: CertificateScheme<PublicKey = P>,
X: Blocker,
D: PeerProvider<PublicKey = P>,
C: CodingScheme,
H: Hasher,
B: CertifiableBlock,
P: PublicKey,
T: Strategy,{ /* private fields */ }Expand description
A network layer for broadcasting and receiving CodedBlocks as Shards.
When enough Shards are present in the mailbox, the Engine may facilitate
reconstruction of the original CodedBlock and notify any subscribers waiting for it.
Implementations
Sourceimpl<E, S, X, D, C, H, B, P, T> Engine<E, S, X, D, C, H, B, P, T>where
E: BufferPooler + Rng + Spawner + Metrics + Clock,
S: Provider<Scope = Epoch>,
S::Scheme: CertificateScheme<PublicKey = P>,
X: Blocker<PublicKey = P>,
D: PeerProvider<PublicKey = P>,
C: CodingScheme,
H: Hasher,
B: CertifiableBlock,
P: PublicKey,
T: Strategy,
impl<E, S, X, D, C, H, B, P, T> Engine<E, S, X, D, C, H, B, P, T>where
E: BufferPooler + Rng + Spawner + Metrics + Clock,
S: Provider<Scope = Epoch>,
S::Scheme: CertificateScheme<PublicKey = P>,
X: Blocker<PublicKey = P>,
D: PeerProvider<PublicKey = P>,
C: CodingScheme,
H: Hasher,
B: CertifiableBlock,
P: PublicKey,
T: Strategy,