Types for erasure coding.
Structs
- Coded
Block - An envelope type for an erasure coded
Block. - Shard
- A broadcastable shard of erasure coded data, including the coding commitment and the configuration used to code the data.
- Stored
Coded Block - A
CodedBlockpaired with itsCommitmentfor efficient storage and retrieval.
Functions
- coding_
config_ for_ participants - Compute the
CodingConfigfor a given number of participants. - hash_
context - Hashes a consensus context for inclusion in a
Commitment.