pub enum DistributionShard<C: Scheme> {
Strong(C::StrongShard),
Weak(C::WeakShard),
}Expand description
A shard of erasure coded data, either a strong shard (from the proposer) or a weak shard (from a non-proposer).
A weak shard cannot be checked for validity on its own.
Variants
Strong(C::StrongShard)
A shard that is broadcasted by the proposer, containing extra information for generating checking data.
Weak(C::WeakShard)
A shard that is broadcasted by a non-proposer, containing only the shard data.