pub struct CodedBlock<B: Block, C: Scheme, H: Hasher> { /* private fields */ }Expand description
An envelope type for an erasure coded Block.
Implementations
Sourceimpl<B: Block, C: Scheme, H: Hasher> CodedBlock<B, C, H>
impl<B: Block, C: Scheme, H: Hasher> CodedBlock<B, C, H>
Sourcepub fn new(inner: B, config: CodingConfig, strategy: &impl Strategy) -> Self
pub fn new(inner: B, config: CodingConfig, strategy: &impl Strategy) -> Self
Create a new CodedBlock from a Block and a configuration.
Sourcepub fn new_trusted(inner: B, commitment: Commitment) -> Self
pub fn new_trusted(inner: B, commitment: Commitment) -> Self
Create a new CodedBlock from a Block and trusted Commitment.
Sourcepub const fn config(&self) -> CodingConfig
pub const fn config(&self) -> CodingConfig
Returns the coding configuration for the data committed.
Sourcepub fn shards(&mut self, strategy: &impl Strategy) -> &[C::Shard]
pub fn shards(&mut self, strategy: &impl Strategy) -> &[C::Shard]
Returns a reference to the shards in this coded block.
If the shards have not yet been generated, they will be created via Scheme::encode.
Sourcepub fn shard(&self, index: u16) -> Option<Shard<C, H>>where
B: CertifiableBlock,
pub fn shard(&self, index: u16) -> Option<Shard<C, H>>where
B: CertifiableBlock,
Returns a Shard at the given index, if the index is valid.
Sourcepub fn into_inner(self) -> B
pub fn into_inner(self) -> B
Takes the inner Block.