pub struct Shard<C: Scheme, H: Hasher> { /* private fields */ }Expand description
A broadcastable shard of erasure coded data, including the coding commitment and the configuration used to code the data.
Implementations
Sourceimpl<C: Scheme, H: Hasher> Shard<C, H>
impl<C: Scheme, H: Hasher> Shard<C, H>
pub const fn new(commitment: Commitment, index: u16, inner: C::Shard) -> Self
Sourcepub const fn commitment(&self) -> Commitment
pub const fn commitment(&self) -> Commitment
Returns the Commitment for this shard.
Sourcepub fn into_inner(self) -> C::Shard
pub fn into_inner(self) -> C::Shard
Takes the inner shard.