pub struct Floor { /* private fields */ }Expand description
Durable height and round bounds restored when marshal initializes.
The components are independent retention bounds and need not identify the same finalization.
Implementations