pub enum Finalized {
ByHeight {
height: Height,
},
ByRound {
round: Round,
},
}Expand description
Metadata for a finalized block requested by commitment.
Variants
ByHeight
The finalized height is known before the request.
ByRound
Only the finalization round is known before the request.
This happens when a finalization names the block commitment but not the block height.