pub enum RandomVersion {
V0,
V1,
}Expand description
Signature-to-leader mapping used by Random.
Variants
V0
👎Deprecated:
mapping encoded threshold signature directly to participants can bias selection
Maps the encoded threshold signature directly to a participant.
V1