CertificateVerifier

Trait CertificateVerifier 

pub trait CertificateVerifier<D: Digest>: for<'a> Verifier<Subject<'a, D> = Subject<'a, D>> { }
Marker trait for certificate verifiers compatible with simplex.

This trait binds a Verifier to the Subject subject type used by the simplex protocol. It is automatically implemented for any verifier whose subject type matches Subject<'a, D>.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<D: Digest, S> CertificateVerifier<D> for S
where S: for<'a> Verifier<Subject<'a, D> = Subject<'a, D>>,