pub struct ConflictingNotarize<S: Scheme, D: Digest> { /* private fields */ }Expand description
ConflictingNotarize represents evidence of a Byzantine validator sending conflicting notarizes. This is used to prove that a validator has equivocated (voted for different proposals in the same view).
Implementations
Sourceimpl<S: Scheme, D: Digest> ConflictingNotarize<S, D>
impl<S: Scheme, D: Digest> ConflictingNotarize<S, D>
Sourcepub fn new(notarize_1: Notarize<S, D>, notarize_2: Notarize<S, D>) -> Self
pub fn new(notarize_1: Notarize<S, D>, notarize_2: Notarize<S, D>) -> Self
Creates a new conflicting notarize evidence from two conflicting notarizes.
Panics
Panics if the two notarizes do not have the same round and signer, or if they have identical proposals (which would not constitute conflicting evidence).