pub struct Context<D: Digest, P: PublicKey> {
pub round: Round,
pub leader: P,
pub parent: (View, D),
}Expand description
Context is a collection of metadata from consensus about a given payload. It provides information about the current epoch/view and the parent payload that new proposals are built on.
Fields
round: RoundCurrent round of consensus.
leader: PLeader of the current round.
parent: (View, D)Parent the payload is built on.
When the current view is not a term start, the parent must be the immediately previous view. When the current view is a term start, the parent may be an older certified view as long as the participant possesses nullifications covering every skipped term (a nullification covers the view it was created for and the remainder of that term); any uncovered view may eventually be finalized and skipping it would result in a fork. The parent remains valid even if a later nullification in its own term covers the parent view.