pub struct Request {
pub id: u64,
pub notarizations: Vec<View>,
pub nullifications: Vec<View>,
}Expand description
Request is a message to request missing notarizations and nullifications. This is used by validators who need to catch up with the consensus state.
Fields
id: u64Unique identifier for this request (used to match responses)
notarizations: Vec<View>Views for which notarizations are requested
nullifications: Vec<View>Views for which nullifications are requested
Implementations