pub trait CertifiableBlock: Block {
type Context: Clone + Encode;
// Required method
fn context(&self) -> Self::Context;
}Expand description
CertifiableBlock extends Block with consensus context information.
This trait is required for blocks used with deferred verification in CertifiableAutomaton. It allows the verification context to be derived directly from the block when a validator needs to participate in certification but never verified the block locally (necessary for liveness).
The Digestible implementation for a CertifiableBlock must commit to the block’s
embedded consensus context. In other words, changing CertifiableBlock::context for a
block must also change Digestible::digest.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".