pub trait Epochable {
// Required method
fn epoch(&self) -> Epoch;
}Expand description
Epochable is a trait that provides access to the epoch number. Any consensus message or object that is associated with a specific epoch should implement this.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".