pub trait Heightable {
// Required method
fn height(&self) -> Height;
}Expand description
Heightable is a trait that provides access to the height. Any consensus message or object that is associated with a specific height should implement this.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".