Roundable

Trait Roundable 

pub trait Roundable: Epochable + Viewable {
    // Provided method
    fn round(&self) -> Round { ... }
}
Roundable is a trait that provides access to the Round number. Any consensus message or object that implements Epochable and Viewable automatically implements this trait.

Provided Methods

fn round(&self) -> Round

Returns the round associated with this object, derived from its epoch and view.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Epochable + Viewable> Roundable for T

Available on neither commonware_stability_GAMMA nor commonware_stability_DELTA nor commonware_stability_EPSILON nor commonware_stability_RESERVED.