pub trait Viewable {
// Required method
fn view(&self) -> View;
}Expand description
Viewable is a trait that provides access to the view (round) number. Any consensus message or object that is associated with a specific view should implement this.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".