Message

Enum Message 

pub enum Message<B, C, H, P>{
    Proposed {
        block: CodedBlock<B, C, H>,
        round: Round,
    },
    Discovered {
        commitment: Commitment,
        leader: P,
        round: Round,
    },
    GetByCommitment {
        commitment: Commitment,
        response: Sender<Option<Arc<CodedBlock<B, C, H>>>>,
    },
    GetByDigest {
        digest: B::Digest,
        response: Sender<Option<Arc<CodedBlock<B, C, H>>>>,
    },
    SubscribeShard {
        commitment: Commitment,
        response: Sender<()>,
    },
    SubscribeByCommitment {
        commitment: Commitment,
        response: Sender<Arc<CodedBlock<B, C, H>>>,
    },
    SubscribeByDigest {
        digest: B::Digest,
        response: Sender<Arc<CodedBlock<B, C, H>>>,
    },
    Prune {
        through: Commitment,
    },
}
A message that can be sent to the coding Engine.

Variants



Proposed

A request to broadcast a proposed CodedBlock to all peers.

Fields

block: CodedBlock<B, C, H>

The erasure coded block.

round: Round

The round in which the block was proposed.



Discovered

A notification from consensus that a Commitment has been discovered.

Fields

commitment: Commitment

The Commitment of the proposed block.

leader: P

The leader’s public key.

round: Round

The round in which the commitment was proposed.



GetByCommitment

A request to get a reconstructed block, if available.

Fields

commitment: Commitment

The Commitment of the block to get.

response: Sender<Option<Arc<CodedBlock<B, C, H>>>>

The response channel.



GetByDigest

A request to get a reconstructed block by its digest, if available.

Fields

digest: B::Digest

The digest of the block to get.

response: Sender<Option<Arc<CodedBlock<B, C, H>>>>

The response channel.



SubscribeShard

A request to open a subscription for the receipt of our valid shard from the leader.

Fields

commitment: Commitment

The block’s commitment.

response: Sender<()>

The response channel.



SubscribeByCommitment

A request to open a subscription for the reconstruction of a CodedBlock by its Commitment.

Fields

commitment: Commitment

The block’s digest.

response: Sender<Arc<CodedBlock<B, C, H>>>

The response channel.



SubscribeByDigest

A request to open a subscription for the reconstruction of a CodedBlock by its digest.

Fields

digest: B::Digest

The block’s digest.

response: Sender<Arc<CodedBlock<B, C, H>>>

The response channel.



Prune

A request to prune all caches at and below the given commitment.

Fields

through: Commitment

Inclusive prune target Commitment.