Mailbox

Struct Mailbox 

pub struct Mailbox<B, C, H, P>{ /* private fields */ }
A mailbox for sending messages to the Engine.

Implementations

Source

impl<B, C, H, P> Mailbox<B, C, H, P>

pub const fn new(sender: Sender<Message<B, C, H, P>>) -> Self

Create a new Mailbox with the given sender.

pub async fn proposed(&self, round: Round, block: CodedBlock<B, C, H>)

Broadcast a proposed erasure coded block’s shards to the participants.

pub async fn discovered(&self, commitment: Commitment, leader: P, round: Round)

Inform the engine of an externally proposed Commitment.

pub async fn get( &self, commitment: Commitment, ) -> Option<Arc<CodedBlock<B, C, H>>>

Request a reconstructed block by its Commitment.

pub async fn get_by_digest( &self, digest: B::Digest, ) -> Option<Arc<CodedBlock<B, C, H>>>

Request a reconstructed block by its digest.

pub async fn subscribe_assigned_shard_verified( &self, commitment: Commitment, ) -> Receiver<()>

Subscribe to assigned shard verification for a commitment.

For participants, this resolves once the leader-delivered shard for the local participant index has been verified. Reconstructing the full block from gossiped shards does not resolve this subscription: that block may still be used for later certification, but it is not enough to claim the participant received the shard it is expected to echo.

For proposers, this resolves immediately after the locally built block is cached because they trivially have all shards.

pub async fn subscribe( &self, commitment: Commitment, ) -> Receiver<Arc<CodedBlock<B, C, H>>>

Subscribe to the reconstruction of a CodedBlock by its Commitment.

pub async fn subscribe_by_digest( &self, digest: B::Digest, ) -> Receiver<Arc<CodedBlock<B, C, H>>>

Subscribe to the reconstruction of a CodedBlock by its digest.

pub async fn prune(&self, through: Commitment)

Request to prune all caches at and below the given commitment.