Mailbox

Struct Mailbox 

pub struct Mailbox<B, C, H, P>{ /* private fields */ }
A mailbox for sending messages to the Engine.

Implementations

Source

impl<B, C, H, P> Mailbox<B, C, H, P>

pub const fn new(sender: Sender<Message<B, C, H, P>>) -> Self

Create a new Mailbox with the given sender.

pub async fn proposed(&self, round: Round, block: CodedBlock<B, C, H>)

Broadcast a proposed erasure coded block’s shards to the participants.

pub async fn discovered(&self, commitment: Commitment, leader: P, round: Round)

Inform the engine of an externally proposed Commitment.

pub async fn get( &self, commitment: Commitment, ) -> Option<Arc<CodedBlock<B, C, H>>>

Request a reconstructed block by its Commitment.

pub async fn get_by_digest( &self, digest: B::Digest, ) -> Option<Arc<CodedBlock<B, C, H>>>

Request a reconstructed block by its digest.

pub async fn subscribe_shard(&self, commitment: Commitment) -> Receiver<()>

Subscribe to the receipt of our valid shard from the leader.

pub async fn subscribe( &self, commitment: Commitment, ) -> Receiver<Arc<CodedBlock<B, C, H>>>

Subscribe to the reconstruction of a CodedBlock by its Commitment.

pub async fn subscribe_by_digest( &self, digest: B::Digest, ) -> Receiver<Arc<CodedBlock<B, C, H>>>

Subscribe to the reconstruction of a CodedBlock by its digest.

pub async fn prune(&self, through: Commitment)

Request to prune all caches at and below the given commitment.