pub struct Marshaled<E, A, B, C, H, Z, S, ES>where
E: Rng + Storage + Spawner + Metrics + Clock,
A: Application<E>,
B: CertifiableBlock<Context = Context<Commitment, <Z::Scheme as CertificateScheme>::PublicKey>>,
C: CodingScheme,
H: Hasher,
Z: Provider<Scope = Epoch, Scheme: Scheme<Commitment>>,
S: Strategy,
ES: Epocher,{ /* private fields */ }Expand description
An Application adapter that handles epoch transitions and erasure coded broadcast.
This wrapper intercepts consensus operations to enforce epoch boundaries. It prevents blocks from being produced outside their valid epoch and handles the special case of re-proposing boundary blocks during epoch transitions.
Implementations
Sourceimpl<E, A, B, C, H, Z, S, ES> Marshaled<E, A, B, C, H, Z, S, ES>where
E: Rng + Storage + Spawner + Metrics + Clock,
A: VerifyingApplication<E, Block = B, SigningScheme = Z::Scheme, Context = Context<Commitment, <Z::Scheme as CertificateScheme>::PublicKey>>,
B: CertifiableBlock<Context = <A as Application<E>>::Context>,
C: CodingScheme,
H: Hasher,
Z: Provider<Scope = Epoch, Scheme: Scheme<Commitment>>,
S: Strategy,
ES: Epocher,
impl<E, A, B, C, H, Z, S, ES> Marshaled<E, A, B, C, H, Z, S, ES>where
E: Rng + Storage + Spawner + Metrics + Clock,
A: VerifyingApplication<E, Block = B, SigningScheme = Z::Scheme, Context = Context<Commitment, <Z::Scheme as CertificateScheme>::PublicKey>>,
B: CertifiableBlock<Context = <A as Application<E>>::Context>,
C: CodingScheme,
H: Hasher,
Z: Provider<Scope = Epoch, Scheme: Scheme<Commitment>>,
S: Strategy,
ES: Epocher,
Sourcepub fn new(context: E, cfg: MarshaledConfig<A, B, C, H, Z, S, ES>) -> Self
pub fn new(context: E, cfg: MarshaledConfig<A, B, C, H, Z, S, ES>) -> Self