Module types

Module types 

Types for erasure coding.

Structs

CodedBlock
An envelope type for an erasure coded Block.
Shard
A broadcastable shard of erasure coded data, including the coding commitment and the configuration used to code the data.
StoredCodedBlock
A CodedBlock paired with its Commitment for efficient storage and retrieval.

Functions

coding_config_for_participants
Compute the CodingConfig for a given number of participants.
hash_context
Hashes a consensus context for inclusion in a Commitment.