CodedBlock

Struct CodedBlock 

pub struct CodedBlock<B: Block, C: Scheme, H: Hasher> { /* private fields */ }
An envelope type for an erasure coded Block.

Implementations

Source

impl<B: Block, C: Scheme, H: Hasher> CodedBlock<B, C, H>

pub fn new(inner: B, config: CodingConfig, strategy: &impl Strategy) -> Self

Create a new CodedBlock from a Block and a configuration.

pub fn new_trusted(inner: B, commitment: Commitment) -> Self

Create a new CodedBlock from a Block and trusted Commitment.

pub const fn config(&self) -> CodingConfig

Returns the coding configuration for the data committed.

pub fn shards(&mut self, strategy: &impl Strategy) -> &[C::StrongShard]

Returns a reference to the shards in this coded block.

If the shards have not yet been generated, they will be created via Scheme::encode.

pub fn shard(&self, index: u16) -> Option<Shard<C, H>>

Returns a Shard at the given index, if the index is valid.

pub const fn inner(&self) -> &B

Returns a reference to the inner Block.

pub fn into_inner(self) -> B

Takes the inner Block.