Shard

Struct Shard 

pub struct Shard<C: Scheme, H: Hasher> { /* private fields */ }
A broadcastable shard of erasure coded data, including the coding commitment and the configuration used to code the data.

Implementations

Source

impl<C: Scheme, H: Hasher> Shard<C, H>

pub const fn new( commitment: Commitment, index: u16, inner: DistributionShard<C>, ) -> Self

pub const fn index(&self) -> u16

Returns the index of this shard within the commitment.

pub const fn commitment(&self) -> Commitment

Returns the Commitment for this shard.

pub const fn is_strong(&self) -> bool

Returns true if the inner shard is strong.

pub const fn is_weak(&self) -> bool

Returns true if the inner shard is weak.

pub fn into_inner(self) -> DistributionShard<C>

Takes the inner DistributionShard.

pub fn verify_into_weak(self) -> Option<Self>

Verifies the shard and returns the weak shard for broadcasting if valid.

Returns Some(weak_shard) if the shard is valid and can be rebroadcast, or None if the shard is invalid or already weak.