pub struct Shard<C: Scheme, H: Hasher> { /* private fields */ }Expand description
A broadcastable shard of erasure coded data, including the coding commitment and the configuration used to code the data.
Implementations
Sourceimpl<C: Scheme, H: Hasher> Shard<C, H>
impl<C: Scheme, H: Hasher> Shard<C, H>
pub const fn new( commitment: Commitment, index: u16, inner: DistributionShard<C>, ) -> Self
Sourcepub const fn commitment(&self) -> Commitment
pub const fn commitment(&self) -> Commitment
Returns the Commitment for this shard.
Sourcepub fn into_inner(self) -> DistributionShard<C>
pub fn into_inner(self) -> DistributionShard<C>
Takes the inner DistributionShard.
Sourcepub fn verify_into_weak(self) -> Option<Self>
pub fn verify_into_weak(self) -> Option<Self>
Verifies the shard and returns the weak shard for broadcasting if valid.
Returns Some(weak_shard) if the shard is valid and can be rebroadcast,
or None if the shard is invalid or already weak.