Module handler

Module handler 

Structs

Handler
A handler that forwards requests from the resolver to the marshal actor.
Receiver
Receiver for resolver handler messages.
Request
A marshal backfill fetch with a request and local processing annotation that match.

Enums

Annotation
Local processing annotation for a resolved key.
Finalized
Metadata for a finalized block requested by commitment.
Key
A raw resolver key for backfilling data.

Functions

init
Creates a resolver receiver and handler pair.