Module config

Module config 

Structs

Config
Configuration for the consensus engine.

Enums

Floor
The certified root from which a Simplex instance starts.
ForwardingPolicy
Controls whether and how the engine proactively forwards certified blocks when entering the next view.