Module config
commonware_
consensus
2026.5.0
Module config
Module Items
Structs
Enums
In commonware_
consensus::
simplex
commonware_consensus
::
simplex
Module
config
Structs

Config
Configuration for the consensus engine.
Enums

Floor
The certified root from which a Simplex instance starts.
Forwarding
Policy
Controls whether and how the engine proactively forwards certified blocks when entering the next view.