pub trait CertificateVerifier<D: Digest>: for<'a> Verifier<Subject<'a, D> = Subject<'a, D>> { }
Marker trait for certificate verifiers compatible with simplex.
simplex
This trait binds a Verifier to the Subject subject type used by the simplex protocol. It is automatically implemented for any verifier whose subject type matches Subject<'a, D>.
Verifier
Subject
Subject<'a, D>
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".