pub trait Attributable {
// Required method
fn signer(&self) -> Participant;
}Expand description
Attributable is a trait that provides access to the signer index. This is used to identify which participant signed a given message.
Required Methods
Sourcefn signer(&self) -> Participant
fn signer(&self) -> Participant
Returns the index of the signer (validator) who produced this message.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".