pub trait Block:
Heightable
+ Codec
+ Digestible
+ Send
+ Sync
+ 'static {
// Required method
fn parent(&self) -> Self::Digest;
}Expand description
Block is the interface for a block in the blockchain.
Blocks are used to track the progress of the consensus engine.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.