pub trait Roundable: Epochable + Viewable { // Provided method fn round(&self) -> Round { ... } }
Roundable is a trait that provides access to the Round number. Any consensus message or object that implements Epochable and Viewable automatically implements this trait.
Round
Epochable
Viewable
Returns the round associated with this object, derived from its epoch and view.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
commonware_stability_GAMMA
commonware_stability_DELTA
commonware_stability_EPSILON
commonware_stability_RESERVED